@@ -1,10 +1,10 @@
 # -*- perl -*-
 
 #
-# $Id: Date.pm,v 1.70 2008/09/23 19:28:59 eserte Exp $
+# $Id: Date.pm,v 1.71 2010/10/25 20:10:31 eserte Exp $
 # Author: Slaven Rezic
 #
-# Copyright (C) 1997, 1998, 1999, 2000, 2001, 2005, 2007, 2008 Slaven Rezic. All rights reserved.
+# Copyright (C) 1997, 1998, 1999, 2000, 2001, 2005, 2007, 2008, 2010 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -23,7 +23,7 @@ use Tk::Frame;
 @ISA = qw(Tk::Frame);
 Construct Tk::Widget 'Date';
 
-$VERSION = '0.43';
+$VERSION = '0.44';
 $VERSION = eval $VERSION;
 
 @monlen = (undef, 31, undef, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
@@ -878,7 +878,7 @@ sub _get_week_days {
     return $weekdays if $weekdays;
     eval {
 	my $loc = _get_datetime_locale();
-	my @weekdays = @{ $loc->day_names }; # clone!
+	my @weekdays = @{ $loc->can('day_format_wide') ? $loc->day_format_wide : $loc->day_names }; # clone!
 	unshift @weekdays, pop @weekdays;
 	$weekdays = \@weekdays;
     };
@@ -910,7 +910,7 @@ sub _get_month_names {
     return $monthnames if $monthnames;
     eval {
 	my $loc = _get_datetime_locale();
-	my @monthnames = @{ $loc->month_names }; # clone!
+	my @monthnames = @{ $loc->can('month_format_wide') ? $loc->month_format_wide : $loc->month_names }; # clone!
 	$monthnames = \@monthnames;
     };
     return $monthnames if $monthnames;
@@ -1514,7 +1514,7 @@ Slaven Rezic <eserte@cs.tu-berlin.de>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1997, 1998, 1999, 2000, 2001, 2005, 2007 Slaven Rezic.
+Copyright (C) 1997, 1998, 1999, 2000, 2001, 2005, 2007, 2008, 2010 Slaven Rezic.
 All rights reserved. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
